BridgeError

Enum BridgeError 

pub enum BridgeError {
    NoBridgeSpecified,
    LengthError(usize, usize),
    USBError(Error),
    IoError(Error),
    NotConnected,
    InvalidAddress,
    WrongResponse,
    ProtocolNotSupported,
    Timeout,
}
Errors that are generated while creating or using the Wishbone Bridge.

Variants



NoBridgeSpecified

No bridge was specified (i.e. it was None)



LengthError(usize, usize)

Expected one size, but got another



USBError(Error)

USB subsystem returned an error



IoError(Error)

std::io error



NotConnected

Attempted to communicate with the bridge, but it wasn’t connected



InvalidAddress

The address or path was incorrect



WrongResponse

We got something weird back from the bridge



ProtocolNotSupported

Requested protocol is not supported on this platform



Timeout

We got nothing back from the bridge